Class: Ruact::ServerFunctions::StandaloneDispatcher::Result

Inherits:
Struct
  • Object
show all
Defined in:
lib/ruact/server_functions/standalone_dispatcher.rb

Overview

Plain value object returned by dispatch. The caller — typically EndpointController#dispatch_action when running inside the Rails request cycle — applies these directives via ‘render` / `head` so Rails’ ‘ImplicitRender` does not overwrite the response. In test / benchmark contexts the value can be applied to a bare response via apply_to_response.

Instance Attribute Summary collapse

Instance Attribute Details

#bodyObject

Returns the value of attribute body

Returns:

  • (Object)

    the current value of body



35
36
37
# File 'lib/ruact/server_functions/standalone_dispatcher.rb', line 35

def body
  @body
end

#content_typeObject

Returns the value of attribute content_type

Returns:

  • (Object)

    the current value of content_type



35
36
37
# File 'lib/ruact/server_functions/standalone_dispatcher.rb', line 35

def content_type
  @content_type
end

#statusObject

Returns the value of attribute status

Returns:

  • (Object)

    the current value of status



35
36
37
# File 'lib/ruact/server_functions/standalone_dispatcher.rb', line 35

def status
  @status
end