Class: Ruact::ServerFunctions::StandaloneDispatcher::Result
- Inherits:
-
Struct
- Object
- Struct
- Ruact::ServerFunctions::StandaloneDispatcher::Result
- Defined in:
- lib/ruact/server_functions/standalone_dispatcher.rb
Overview
Plain value object returned by dispatch. The caller — typically EndpointController#dispatch_action when running inside the Rails request cycle — applies these directives via ‘render` / `head` so Rails’ ‘ImplicitRender` does not overwrite the response. In test / benchmark contexts the value can be applied to a bare response via apply_to_response.
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#content_type ⇒ Object
Returns the value of attribute content_type.
-
#status ⇒ Object
Returns the value of attribute status.
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body
35 36 37 |
# File 'lib/ruact/server_functions/standalone_dispatcher.rb', line 35 def body @body end |
#content_type ⇒ Object
Returns the value of attribute content_type
35 36 37 |
# File 'lib/ruact/server_functions/standalone_dispatcher.rb', line 35 def content_type @content_type end |
#status ⇒ Object
Returns the value of attribute status
35 36 37 |
# File 'lib/ruact/server_functions/standalone_dispatcher.rb', line 35 def status @status end |